/*
 *  XNap Commons
 *
 *  Copyright (C) 2005  Steffen Pingel
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.xnap.commons.gui.action;

import java.util.ArrayList;
import java.util.List;
import javax.swing.Action;
import javax.swing.JPopupMenu;
import org.xnap.commons.gui.Builder;

/**
 * 
 * @author Steffen Pingel
 */
public class ActionCollection {
	
	List<Action> actions = new ArrayList<Action>();
	
	public ActionCollection() 
	{
	}

	public void add(Action action)
	{
		actions.add(action);
	}

	public void addSeparator()
	{
		actions.add(null);
	}

	public JPopupMenu createPopupMenu()
	{
		JPopupMenu menu = new JPopupMenu();
		for (Action action : actions) {
			if (action != null) {
				menu.add(Builder.createMenuItem(action));
			}
			else {
				menu.addSeparator();
			}
		}
		return menu;
	}
	
	public Action[] getActions()
	{
		List<Action> result = new ArrayList<Action>(actions.size());
		for (Action action : result) {
			if (action != null) {
				result.add(action);
			}
		}
		return result.toArray(new Action[0]);
	}
	
	public void setSelectedItems(Object[] items)
	{
		for (Action action : actions) {
			if (action instanceof SelectionAction) {
				((SelectionAction)action).setSelectedItems(items);
			}
		}
	}
	
	public boolean isEmpty()
	{
		return actions.isEmpty();
	}
	
}