/*
 *  XNap Commons
 *
 *  Copyright (C) 2005  Steffen Pingel
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.xnap.commons.gui.table;

import java.util.ArrayList;
import java.util.List;
import javax.swing.table.AbstractTableModel;

public abstract class AbstractSimpleTableModel<T> extends AbstractTableModel {

	private Class[] columnClasses;
	
	private List<T> data = new ArrayList<T>(0);
	
	public AbstractSimpleTableModel(Class[] columnClasses) 
	{
		this.columnClasses = columnClasses;
	}
	
	public void add(int index, T item)
	{
		data.add(index, item);
		fireTableRowsInserted(index, index);
	}

	public void add(int index, T[] items)
	{
		for (T item : items) {
			data.add(index, item);
		}
		fireTableRowsInserted(index, index + items.length - 1);
	}

	public void add(T item)
	{
		add(data.size(), item);
	}

	public Class<?> getColumnClass(int column) 
	{
        return columnClasses[column];
    }
	
	public int getColumnCount()
	{
		return columnClasses.length;
	}

	public List<T> getData()
	{
		return data;
	}
	
	public T getItem(int row) 
	{
		return data.get(row);
	}

	public int getRowCount()
	{
		return data.size();
	}

	public abstract Object getValueAt(int row, int column);

	public void remove(int index)
	{
		data.remove(index);
		fireTableRowsDeleted(index, index);
	}

	public void remove(int firstRow, int lastRow)
	{
		for (int i = firstRow; i <= lastRow; i++) {
			data.remove(firstRow);
		}
		fireTableRowsDeleted(firstRow, lastRow);
	}

    public boolean remove(T item)
	{
		int index = data.indexOf(item);
		if (index != -1) {
			data.remove(index);
			fireTableRowsDeleted(index, index);
			return true;
		}
		return false;
	}
	
	public void setData(List<T> data)
	{
		this.data = data;
		fireTableDataChanged();
	}

}