/*
 *  XNap Commons
 *
 *  Copyright (C) 2005  Steffen Pingel
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.xnap.commons.gui.table;

import javax.swing.table.DefaultTableCellRenderer;

/**
 * A cell renderer for {@link Number} objects. 
 */
public class NumberCellRenderer extends DefaultTableCellRenderer {

    private int precision;
	private long minValue;
	private String formatString;

    public NumberCellRenderer(long minValue, int precision) 
    {
		this.minValue = minValue;
		
		setPrecision(precision);
		setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
    }

    public NumberCellRenderer(long minValue)
    {
		this(minValue, 0);
    }

    public NumberCellRenderer()
    {
		this(0, 0);
    }

    /**
     * Sets the position of the decimal separator.
     */
    public void setPrecision(int newValue) 
    {
		setFormatString("%,f." + precision);
    }

	public void setFormatString(String formatString) 
    {
		this.formatString = formatString;
    }

	public String getFormatString()
	{
		return formatString;
	}
	
    public void setValue(Object value) 
    {
		if (value instanceof Number) {
			double d = ((Number)value).doubleValue();
			if (d >= minValue) {
				super.setValue(String.format(formatString, d));
				return;
			}
		}

		super.setValue(null);
    } 
} 
