/*
 *  XNap Commons
 *
 *  Copyright (C) 2005  Steffen Pingel
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.xnap.commons.gui.table;

import java.text.DateFormat;
import java.util.Date;
import javax.swing.table.DefaultTableCellRenderer;
import org.xnap.commons.util.StringHelper;

/**
 * Renders time for a table cell. If the value is an Integer object it
 * is rendered as a length. If value is a Long object it is rendered
 * as absolute time relative to the 1.1.1970.
 */
public class TimeCellRenderer extends DefaultTableCellRenderer
{

	private DateFormat dateFormat;

	public TimeCellRenderer(DateFormat dateFormat) 
    {
		this.dateFormat = dateFormat;
		
		setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
    }

	public TimeCellRenderer() 
    {
		this(DateFormat.getDateInstance());
    }

	protected void setValue(Object value) 
	{
		if (value == null) {
			super.setValue(null);
		}
		else if (value instanceof Integer) {
			int i = ((Number)value).intValue();
			super.setValue((i >= 0) ? StringHelper.formatLength(i) : null);
		}
		else if (value instanceof Long) {
			long l = ((Long)value).longValue();
			super.setValue((l >= 0) ? dateFormat.format(new Date(l)) : null);
		}
		else if (value instanceof Date) {
			super.setValue(dateFormat.format((Date)value));
		}
		else {
			throw new IllegalArgumentException("Expected Integer, Long or java.util.Date; received " + value.getClass());
		}
	}
	
} 
