/*
 *  XNap Commons
 *
 *  Copyright (C) 2005  Felix Berger
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.xnap.commons.gui.tree;

import java.io.File;

public class FileNode extends File 
{

    boolean fullPath;
    String label;

    public FileNode(File f, boolean fullPath, String label)
    {
		super(f, "");
		this.fullPath = fullPath;
		this.label = (label == null) ? "" : label;
    }

    public FileNode(File f, boolean fullPath)
    {
		this(f, fullPath, "");
    }

    public FileNode(File f)
    {
		this(f, false, "");
    }

    @Override
    public boolean equals(Object obj)
    {
		if (obj instanceof FileNode) {
			FileNode f = (FileNode)obj;
			return super.equals(obj) && label.equals(f.label);
		}
		else {
			return super.equals(obj);
		}
    }
    
    @Override
    public int hashCode()
    {
    	return label.hashCode() + 31 * super.hashCode();
    }
    
    public String getLabel()
    {
		return label;
    }
    
    public String toString()
    {
		if (fullPath) {
			return getPath() + label;
		}
		else {
			return getName() + label;
		}
    }
} 
