/*
 *  XNap Commons
 *
 *  Copyright (C) 2005  Steffen Pingel
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.xnap.commons.io;

import java.awt.Component;

/**
 * Defines the requirements for classes that monitor operations
 * to display user visible feedback.
 */
public interface ProgressMonitor { 

	/**
	 * Returns the component that displays the progress. This could be a dialog,
	 * a progress bar or <code>null</code>.
	 * 
	 * @return null, if this monitor is not displayed by a component; the
	 *         component, otherwise
	 */
	Component getComponent();
	
	/**
	 * Returns true, if the operation has been cancelled by the user.
	 */
	boolean isCancelled();
	
	/**
	 * Enables the cancel button.
	 * <p>
	 * Per default we assume cancelling is enabled. 
	 */
	void setCancelEnabled(boolean enabled);
	
	/**
	 * Sets the maximum value.
	 */
	void setTotalSteps(long max);
	
	/**
	 * Sets the current value.
	 *
	 * @param value min <= value <= max
	 */
	void setValue(long value);

	/**
	 * Sets the message text.
	 */
	void setText(String text);

	/**
	 * Increase the value by amount.
	 */
	void work(long amount);

}
