/*
 *  XNap Commons
 *
 *  Copyright (C) 2005  Steffen Pingel
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.xnap.commons.settings;

/**
 * @author Steffen Pingel
 */
public class IntSetting extends AbstractSetting<Integer> {

    public IntSetting(SettingResource backend, String key, Integer defaultValue, int min, int max)
    {
    	super(backend, key, defaultValue, new IntValidator(min, max));
    }

    public IntSetting(SettingResource backend, String key, Integer defaultValue, int min)
    {
    	super(backend, key, defaultValue, new IntValidator(min));
    }

    public IntSetting(SettingResource backend, String key, Integer defaultValue, Validator validator)
    {
    	super(backend, key, defaultValue, validator);
    }

    public IntSetting(SettingResource backend, String key, Integer defaultValue)
    {
    	super(backend, key, defaultValue, null);
    }
    
    protected Integer fromString(String value)
	{
    	try {
    		return new Integer(value);
    	}
    	catch (NumberFormatException e) {
    		return null;
    	}
	}

	protected String toString(Integer value)
	{
		return value.toString();
	}

}
